@@ -10,14 +10,14 @@ import time
 import matplotlib.pyplot as plt
 from matplotlib import font_manager
 from matplotlib.ticker import MaxNLocator
+from rich.console import Console
 
-from opencv_webcam.utils.fonts_opt import info_warning
 from opencv_webcam.utils.time_format import time_format
 
-OWS_VERSION = "OpenCV Webcam Script v0.8"  # 项目名称与版本号
+OWS_VERSION = "OpenCV Webcam Script v0.9"  # 项目名称与版本号
 ROOT_PATH = sys.path[0]  # 项目根目录
 
-# ---------------------颜色列表---------------------
+# --------------------- 颜色列表 ---------------------
 COLOR_LIST = [
     "#f96801",
     "#800000",
@@ -34,10 +34,9 @@ COLOR_LIST = [
     "#704214",
     "#50C878",
     "#DE3163",
-    "#003153",
-]
+    "#003153",]
 
-# ---------------------字体库---------------------
+# --------------------- 字体库 ---------------------
 SimSun_path = f"{ROOT_PATH}/fonts/SimSun.ttc"  # 宋体文件路径
 TimesNesRoman_path = f"{ROOT_PATH}/fonts/TimesNewRoman.ttf"  # 新罗马字体文件路径
 # 宋体
@@ -45,12 +44,14 @@ SimSun = font_manager.FontProperties(fname=SimSun_path, size=12)
 # 新罗马字体
 TimesNesRoman = font_manager.FontProperties(fname=TimesNesRoman_path, size=12)
 
+console = Console()
+
 
 # 创建折线图
 def createLineChart(frames_y, date_list, time_list, fdn_list, fsd_list):
     chart_startTime = time.time()  # 作图开始时间
 
-    # ---------------------作图开始---------------------
+    # --------------------- 作图开始 ---------------------
     fdn_list_cls = list(set(fdn_list))  # 去重
     fdn_list_cls.sort(key=fdn_list.index)  # 顺序
     for i in range(len(fdn_list_cls)):
@@ -66,6 +67,10 @@ def createLineChart(frames_y, date_list, time_list, fdn_list, fsd_list):
 
         plt.figure(figsize=(8, 4))  # 画布尺寸
         plt.cla()  # 清除axes
+
+        # Using categorical units to plot a list of strings that are all parsable as floats or dates. If these strings should be plotted as numbers, cast to the appropriate data type before plotting.
+        plt.set_loglevel("WARNING")
+
         # 设置线型
         plt.plot(
             tmp_time,
@@ -100,7 +105,7 @@ def createLineChart(frames_y, date_list, time_list, fdn_list, fsd_list):
             # plt.text(a, b, f'{c}', ha='center', va='top',
             #          fontsize=10.5, fontproperties=TimesNesRoman)
 
-        # ---------------------标题、横纵轴、图例等---------------------
+        # --------------------- 标题、横纵轴、图例等 ---------------------
         # 标题
         plt.title(OWS_VERSION, fontsize=12, fontproperties=TimesNesRoman)
         # 横轴标签，时间
@@ -114,29 +119,25 @@ def createLineChart(frames_y, date_list, time_list, fdn_list, fsd_list):
         # 图例
         plt.legend(prop=SimSun, fontsize=12, loc="best")
 
-        # ---------------------chart保存信息---------------------
+        # --------------------- chart保存信息 ---------------------
         # 创建DateFrames目录，以日期为子目录
         os.makedirs(f"{ROOT_PATH}/DateFrames/{date_list[i]}", exist_ok=True)
         # 图片路径，以类别为图片名称
-        date_frames_chart_path = (
-            f"{ROOT_PATH}/DateFrames/{date_list[i]}/{fdn_list_cls[i]}.png"
-        )
+        date_frames_chart_path = (f"{ROOT_PATH}/DateFrames/{date_list[i]}/{fdn_list_cls[i]}.png")
         # 保存图像
         plt.savefig(date_frames_chart_path, dpi=300, bbox_inches="tight")
 
-        # ---------------------作图结束---------------------
+        # --------------------- 作图结束 ---------------------
         chart_endTime = time.time()  # 作图结束时间
         chart_totalTime = chart_endTime - chart_startTime  # 作图用时
-        print(
-            f'{info_warning("日期-帧数图创建成功！")[1]}{info_warning("用时：")[0]}{time_format(chart_totalTime)}，'
-            f'{info_warning("已保存在")[0]}{date_frames_chart_path}，{info_warning("总帧数：")[0]}{sum(frames_y)}'
-        )
+        console.print(f"[bold green]日期-帧数图创建成功！[/bold green][bold blue]用时：[/bold blue]{time_format(chart_totalTime)}，"
+                      f"[bold blue]已保存在[/bold blue]{date_frames_chart_path}，[bold blue]总帧数：[/bold blue]{sum(frames_y)}")
     plt.close()  # 关闭窗口
 
 
 # csv2chart
 def csv2chart(csv_path):
-    f = open(csv_path, "r")  # 读取csv
+    f = open(csv_path)  # 读取csv
     f_list = list(csv.reader(f))  # csv2list
 
     d_list = []  # 日期列表
@@ -153,7 +154,7 @@ def csv2chart(csv_path):
         if tmp_date != date_item:
             createLineChart(frames_list, d_list, t_list, fdn_list, fsd_list)  # 创建日期-帧数图
             tmp_date = date_item  # 替换
-            # -----------清空列表-----------
+            # ----------- 清空列表 -----------
             d_list = []  # 日期列表
             t_list = []  # 时间列表
             frames_list = []  # 帧数列表
